<?php

if( ! defined( 'ABSPATH' ) ) exit;

if( !class_exists( 'task_controller_01' ) ) {
	class task_controller_01 extends post_ctr_01 {
		protected $model_name 	= 'task_model_01';
		protected $post_type	= 'wpeo-task';
		protected $meta_key		= 'wpeo_task';
		
		/** Défini la route par défaut permettant d'accèder aux tâches depuis WP Rest API  / Define the default route for accessing to task from WP Rest API */
		protected $base = 'task';
		protected $version = '0.1';
		
		/**
		 * Call some wordpress action : init, admin_menu, admin_enqueue_scripts and admin_print_scripts and add_meta_boxes
		 * Add filter "the_content" for add point in front view
		 * Install all module in module/folder
		 * @return void
		 */
		public function __construct() {
			parent::__construct();
			
			/** Inclus le modèle */
			include_once( WPEOMTM_TASK_PATH . '/model/task.model.01.php' );
			
			add_action( 'init', array( &$this, 'callback_init' ), 1, 0 );
			add_action( 'admin_menu', array( &$this, 'callback_admin_menu' ), 1 );
			add_action( 'admin_enqueue_scripts', array( &$this, 'callback_admin_enqueue_scripts' ), 1 );
			add_action( 'wp_enqueue_scripts', array( &$this, 'callback_enqueue_scripts' ), 1 );
	 		add_action( 'admin_print_scripts', array( &$this, 'callback_admin_print_scripts' ) );
	 		
	 		/** Metabox */
	 		add_action( 'add_meta_boxes', array( $this, 'callback_add_meta_boxes' ), 10, 2 );
	 		
	 		/** Filter the content */
	 		add_filter( 'the_content', array( $this, 'callback_the_content' ) );
	 		
	 		/** Shortcode pour afficher une tâche */
	 		add_shortcode( 'wpeo_task', array( $this, 'callback_shortcode' ) );
	 		
	 		/** Pour WPShop */
	 		add_filter( 'wps_my_account_extra_part_menu', array( $this, 'callback_my_account_menu' ) );
	 		add_filter( 'wps_my_account_extra_panel_content', array( $this, 'callback_my_account_content' ), 10, 2 );
	 		
	 		wpeo_util::install_in('module');
		}
		
		public function callback_register_route( $array_route ) {
			$array_route = parent::callback_register_route( $array_route );
			
// 			$array_route['/' . $this->version . '/post/' . $this->base . '/search/tag' ] = array(
// 					array( array( $this, 'search_tag' ), WP_JSON_Server::CREATABLE | WP_JSON_Server::ACCEPT_JSON )
// 			);
	
			return $array_route;
		}
				
		/**
		 * Déclare le post type pour wpeo-task
		 * 
		 * @return void
		 */
		public function callback_init() {
			
			/** Task post type */
			$labels = array(
				'name'                	=> __('Tasks', 'task-manager'),
				'singular_name'       	=> __('Task', 'task-manager'),
				'menu_name'           	=> __('Tasks', 'task-manager'),
				'parent_item_colon'   	=> __('Parent Task:', 'task-manager'),
				'all_items'           	=> __('Tasks', 'task-manager'),
				'view_item'           	=> __('View Task', 'task-manager'),
				'add_new_item'        	=> __('Add New Task', 'task-manager'),
				'add_new'             	=> __('New Task', 'task-manager'),
				'edit_item'           	=> __('Edit Task', 'task-manager'),
				'update_item'         	=> __('Update Task', 'task-manager'),
				'search_items'        	=> __('Search Tasks', 'task-manager'),
				'not_found'           	=> __('No tasks found', 'task-manager'),
				'not_found_in_trash'  	=> __('No tasks found in Trash', 'task-manager'),
			);
			$args = array(
				'label'               	=> __('Tasks', 'task-manager'),
				'description'         	=> __('Tasks management', 'task-manager'),
				'labels'              	=> $labels,
				'supports'            	=> null,
				'hierarchical'        	=> true,
				'public'              	=> true,
				'show_ui'             	=> true,
				'show_in_menu'        	=> false,
				'show_in_json'			=> true,
				'show_in_nav_menus'   	=> true,
				'show_in_admin_bar'   	=> true,
				'can_export'          	=> true,
				'has_archive'         	=> true,
				'exclude_from_search' 	=> true,
				'publicly_queryable'  	=> true,
			);
			
			register_post_type($this->post_type, $args);			
		}
			
		/**
		 * Ajoutes la page dans le menu nécessaire pour le fonctionnement de ce plugin : 
		 * task manager
		 * 
		 * @return void
		 */
		public function callback_admin_menu() {
			add_menu_page( __( 'Task management dashboard', 'task-manager' ), __( 'Tasks manager', 'task-manager' ), 'manage_options', 'wpeomtm-dashboard', array( &$this, 'callback_menu_page_dashboard' ), 'dashicons-layout' );		
			add_submenu_page( 'wpeomtm-dashboard', __( 'Task management dashboard', 'task-manager' ), __( 'Tasks manager', 'task-manager' ), 'manage_options', 'wpeomtm-dashboard', array( &$this, 'callback_menu_page_dashboard' ) );
		}
		
		/**
		 * Inclus les javascripts et css nécessaire pour le fonctionnement de ce plugin.
		 * 
		 * @return void
		 */
		public function callback_admin_enqueue_scripts() {
			wp_enqueue_script( 'wpeo-chosen-js', WPEOMTM_TASK_URL . '/asset/js/chosen.jquery.js', array( "jquery" ), WPEOMTM_TASK_VERSION );
			wp_enqueue_script( 'eoajax', WPEOMTM_TASK_URL . '/asset/js/eoajax.js', array( "jquery" ), WPEOMTM_TASK_VERSION );
			wp_enqueue_script( 'wpeo-task-backend-js', WPEOMTM_TASK_URL . '/asset/js/backend.js', array( "jquery", "jquery-form", "jquery-ui-datepicker", "jquery-ui-sortable", "jquery-masonry" ), WPEOMTM_TASK_VERSION );

			wp_register_style( 'wpeo-task-css', WPEOMTM_TASK_URL . '/asset/css/style.css', '', WPEOMTM_TASK_VERSION );
			wp_register_style( 'jquery-ui', '//code.jquery.com/ui/1.11.4/themes/smoothness/jquery-ui.css', '', WPEOMTM_TASK_VERSION );
			
			wp_register_style( 'wpeo-task-flextext-css', WPEOMTM_TASK_URL . '/asset/css/flextext.css', '', WPEOMTM_TASK_VERSION );
			wp_enqueue_style( 'wpeo-task-css' );
			wp_enqueue_style( 'wpeo-task-flextext-css' );
			wp_enqueue_style( 'dashicons' );
			wp_enqueue_style( 'jquery-ui' );
		}
		
		/**
		 * Inclus le fichier frontend.css
		 * 
		 * @return void
		 */
		public function callback_enqueue_scripts() {
			wp_register_style( 'wpeo-task-frontend-css', WPEOMTM_TASK_URL . '/asset/css/frontend.css', '', WPEOMTM_TASK_VERSION );
			wp_enqueue_style( 'wpeo-task-frontend-css' );
		}
		
		/**
		 * Inclus le fichier language.js.php pour la traduction des texte en Javascript.
		 * 
		 * @return void
		 */
		public function callback_admin_print_scripts() {
			require( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_ASSETS_DIR, "js", "language.js") );
		}
			
		/**
		* Charges toutes les tâches, les parcours pour récupérer toutes les informations requises
		* pour le template. Apelle le template dashboard-main.
		* 
		* @return void
		*/
		public function callback_menu_page_dashboard() {		
			/** Charges toutes les tâches */
			$list_task = $this->index( array( 'post_parent' => 0 ) );
			
			global $point_action;
			$list_comment_template = $point_action->ajax_load_last_comment( 1 );
																		
			require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'dashboard', 'main' ) );
		}
	
		/*
		 * Ajoutes une metabox sur tous les post type
		 * 
		 * @return void
		 */
		public function callback_add_meta_boxes($post_type, $post) {
			add_meta_box('wpeo-tasks-metabox', __('Task', 'task-manager'), array($this, 'callback_render_metabox'), $post_type, 'normal', 'default');
		}
		
		/**
		 * Le rendu des meta box
		 * 
		 * @param WP_Post $post
		 * @return void
		 */
		public function callback_render_metabox($post) {
			$list_task = $this->index( array( 'post_parent' => $post->ID ) );
			$custom_class = 'wpeo-project-wrap-custom';
			
			require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'dashboard', 'main' ) );
		}
	
		public function callback_the_content($content) {
			if($GLOBALS['post']->post_type !== 'wpeo-task')
				return $content;
		
			$task = $this->show( $GLOBALS['post']->ID );
			
			global $point_controller_01;
		
			ob_start();
			$point_controller_01->render_point_frontend( $task );
			$content .= ob_get_clean();
		
			return $content;
		}

		/** Récupères les tâches par rapport au term_id de celle-ci.
		 * 
		 * @param array $list_term_id Array of term_id
		 * @return multitype:object
		 */
		public function get_task_by_term_id( $list_term_id ) {
			$tax_query = array();

			if ( empty( $list_term_id ) )
				return null;
			
			global $task_controller;
			global $tag_controller;
						
			$tax_query = array(
				array(
					'taxonomy' => $tag_controller->get_taxonomy(),
					'field' => 'term_id',
					'terms' => $list_term_id,
					'operator' => 'AND',
				)
			);
						
			$list_task = get_posts( array( 
				'posts_per_page' => -1,
				'tax_query' => $tax_query,
				'post_type' => $task_controller->get_post_type(),
			) );
		
			return $list_task;
		}
		
		public function get_task_by_user_id( $list_user_id ) {
			if ( empty( $list_user_id ) )
				return null;
			
			global $task_controller;
			global $wpdb;
			
			$query = "SELECT post.ID FROM {$wpdb->posts} as post INNER JOIN {$wpdb->postmeta} as postmeta ON ( post.ID = postmeta.post_id )
				WHERE 1=1  AND";
			
			$i = 0;
			
			foreach ( $list_user_id as $user_id ) {
				$user_id = intval( $user_id );
				if ( !empty( $i ) ) {
					$query .= ' AND ';
				}
				$query .= " ( ( postmeta.meta_key = 'wpeo_task' AND CAST(postmeta.meta_value AS CHAR) LIKE '%affected_id\":[".$user_id."]%' )
						OR ( postmeta.meta_key = 'wpeo_task' AND CAST(postmeta.meta_value AS CHAR) LIKE '%affected_id\":[%,".$user_id."]%' ) 
  						OR ( postmeta.meta_key = 'wpeo_task' AND CAST(postmeta.meta_value AS CHAR) LIKE '%affected_id\":[".$user_id.",%]%' ) )";
				
				$i++;
			}
			
			$query .= " AND  ( postmeta.meta_key = 'wpeo_task' AND CAST(postmeta.meta_value AS CHAR) NOT LIKE '%affected_id\":[]%' ) 
				AND post.post_type = 'wpeo-task' 
				AND 
					(
						post.post_status = 'publish' 
						OR post.post_status = 'future' 
						OR post.post_status = 'draft' 
						OR post.post_status = 'pending' 
						OR post.post_status = 'private'
					) 
				GROUP BY post.ID ORDER BY post.post_date DESC ";
						
			$list_task = $wpdb->get_results( $query );			
						
			return $list_task;
		}
		
		/**
		 * Remplis toutes les informations supplémentaire nécesseraire à la tâche: les points,
		 * les utilisateurs associées, le responsable de la tâche, les catégories de la tâche,
		 * si elle est archivé ou non et si c'est une tâche à l'utilisateur courant ou non.
		 * 
		 * @param task_model_01 $task L'objet tâche
		 * @return task_model_01
		 */
		public function get_task_information( $task ) {
			global $tag_controller;
			
			/** Cette fonction récupère tous les points associés à la tâche */
			$task->point = 	$this->get_point( $task->option['task_info']['order_point_id'] );
			
			/** On verifie si le module des catégories existe, si oui, on apelle la fonction pour récupérer les catégories de la tâche. */
			$task->class = class_exists( 'tag_controller_01' ) ? $this->get_tag( $task->taxonomy[ $tag_controller->get_taxonomy() ] ) : '';
			$task->class .= class_exists( 'tag_controller_01' ) ? $this->get_is_archive( $task ) : '';
			
			$task->class .= $this->get_my_task( $task );
			$task->class .= $this->get_affected_task( $task );
			$task->class .= $this->get_other_user_affected( $task );
					
			return $task;
		}
		
		/**
		 * Récupères tous les points dans la tâche selon l'order de $order_point_id
		 * 
		 * @param array $order_point_id L'ordre des points.
		 * @return array( point_model_01 )
		 */
		public function get_point( $order_point_id ) {
			global $point_controller;
			
			$array_point = array();
		
			if( !empty( $order_point_id ) ) {
				foreach( $order_point_id as $point_id ) {
					$array_point[$point_id] = $point_controller->show( $point_id );
				}
			}
		
			return $array_point;
		}
		
		/**
		 * Utilises le modèle $tag_controller pour récupérer toutes les catégories affectées à 
		 * cette tâche. Renvoie une chaine de caractère qui correspond à tout les slug de catégorie
		 * associé à celle-ci.
		 * 
		 * @param array $list_tag_id La liste des term_id des tags
		 * @return string
		 */
		public function get_tag( $list_tag_id ) {
			global $tag_controller;
	
			$class = '';
			
			if ( !empty( $list_tag_id  ) ) {
				foreach ( $list_tag_id as $tag_id ) {
					$tag_tmp = $tag_controller->show($tag_id);
					$class .= 'wpeo-' . $tag_tmp->slug . ' ';
				}
				
				$class = substr($class, 0, -1);
	
			} 
			return $class;
		}
		
		/**
		 * Vérifie si le responsable de la tâche et l'utilisateur courant, si c'est le cas ajoute
		 * la class wpeo-my-task
		 * @param task_model_01 $task L'objet tâche
		 * @return string
		 */
		public function get_my_task( $task ) {
			$my_task = '';
			
			$user_id = get_current_user_id();
			
			if ( $task->option['user_info']['owner_id'] == $user_id ) {
				$my_task = 'wpeo-my-task ';
			}
			
			/** Cette espace permet d'avoir une séparation entre les catégories et cette chaine de caractère */
			return ' ' . $my_task;
		}
		
		/**
		 * Vérifie si le tag archive est présent dans la tâche. Si c'est le cas renvoie
		 * wpeo_is_archive
		 *
		 * @param task_model_01 $task L'objet de la tâche
		 * @return string
		 */
		public function get_is_archive( $task ) {
			global $tag_controller;
				
			$is_archive = '';
				
			$term = get_term_by( 'slug', 'archive', $tag_controller->get_taxonomy() );
				
			if ( !empty( $term ) ) {
				if( in_array( $term->term_id, $task->taxonomy[$tag_controller->get_taxonomy()] ) ) {
					$is_archive = ' wpeo-is-archive ';
				}
			}
			
			/** Cette espace permet d'avoir une séparation entre wpeo-my-task et cette chaine de caractère */
			return $is_archive;
		}
		
		/**
		 * Vérifie si l'utilisateur courant est affecté dans le tableau affected_id
		 * 
		 * @param task_model_01 $task L'objet de la tâche
		 * @return string
		 */
		public function get_affected_task( $task ) {
			$affected_task = '';
			
			$user_id = get_current_user_id();
	
			if ( in_array( $user_id, $task->option['user_info']['affected_id'] ) ) {
				$affected_task = ' wpeo-affected-task ';
			}
			
			/** Cette espace permet d'avoir une séparation entre wpeo-is-archive et cette chaine de caractère */
			return $affected_task;
		}
		
		/**
		 * Récupères tous les autres utilisateurs affectées à la tâche également les responsables,
		 * si un de ses utilisateurs est dans la tâche, ajoutes la class wpeo-user-<id>.
		 * 
		 * @param task_model_01 $task L'objet de la tâche
		 * @return string
		 */
		public function get_other_user_affected( $task ) {
			$other_user_affected = '';
			
			global $wp_project_user_controller;
			
			if ( !empty( $wp_project_user_controller->list_user ) ) {
				foreach ( $wp_project_user_controller->list_user as $user ) {
					if ( in_array( $user->id, $task->option['user_info']['affected_id'] ) || $user->id === $task->option['user_info']['owner_id'] ) {
						$other_user_affected .= ' wpeo-user-' . $user->id . ' ';
					}
				}
			}
			
			return $other_user_affected;
		}
	
		/**
		 * Récupères les tâches ou l'utilisateur $user_id à commenté
		 * 
		 * @param int $user_id L'utilisateur id
		 * @return NULL|Array $task_model
		 */
		public function get_task_by_comment_user_id( $user_id ) {
			if ( empty( $user_id ) )
				return null;
			
			global $point_controller;
			
			$list_point = $point_controller->get_list_point_by_comment_user_id( $user_id );
			$list_task = array();
			
			if ( !empty( $list_point ) ) {
				foreach( $list_point as $point ) {
					$list_task[] = $this->show( $point->post_id );
				}
			}
			
			return $list_task;
		}
		
		/**
		 * Récupères toutes les tâches ou l'utilisateur $user_id à commenté et ou les
		 * $start_date et $end_date corresponde.
		 *
		 * @param int $user_id L'id de l'utilisateur
		 * @param string $start_date La date minimum
		 * @param string $end_date La date maximum
		 * @return NULL|Array task_model
		 */
		public function get_task_by_comment_user_id_and_date( $user_id, $start_date, $end_date ) {
			global $point_controller;
				
			$list_point = $point_controller->get_list_point_by_comment_user_id_and_date( $user_id, $start_date, $end_date );
			$list_task = array();
				
			if ( !empty( $list_point ) ) {
				foreach( $list_point as $point ) {
					$list_task[$point->post_id] = $this->show( $point->post_id );
				}
			}
				
			return $list_task;
		}
		
		public function get_task_created_by_user_id_and_date( $user_id, $start_date, $end_date ) {
			if ( empty( $user_id ) || empty( $start_date ) || empty( $end_date ) )
				return 0;
				
			global $wpdb;
				
			$query =
				"SELECT ID
				FROM {$wpdb->posts}
				WHERE	post_author = %d AND
						post_date BETWEEN %s AND %s AND
						post_type = %s";
				
			$list_task = $wpdb->get_results( $wpdb->prepare( $query, array( $user_id, $start_date, $end_date, 'wpeo-task' ) ) );
			$list_task_model = array();
			
			if ( !empty( $list_task ) ) {
				foreach( $list_task as $task ) {
					$list_task_model[] = $this->show( $task->ID );
				}
			}
			
			return $list_task_model;
		}
		
		public static function get_task_title_by_id( $task_id ) {
			if( empty( $task_id ) )
				return __( 'Task not found', 'task-manager' );
				
			global $task_controller;
			$task = $task_controller->show( $task_id );
				
			if( empty( $task ) )
				return __( 'Task not found', 'task-manager' );
				
			return $task->title;
		}
		
		/**
		 * Récupères tous les temps des points et les compiles dans 
		 * $task->option['time_info']['elapsed']
		 * 
		 * @param int $id L'ID de la tâche
		 * @return task_model_01 L'objet de la tâche
		 */
		public function update_time( $id ) {
			$task = $this->show( $id );
			
			$time_elapsed = 0;
			
			/** Récupères tous les points */
			$task->point = $this->get_point( $task->option['task_info']['order_point_id'] );
			
			if( !empty( $task->point ) ) {
				foreach( $task->point as $point ) {
					$time_elapsed += $point->option['time_info']['elapsed'];
				}
			}
				
			$task->option['time_info']['elapsed'] = $time_elapsed;
			$this->update( $task );
			
			return $task;
		}
		
		public function callback_shortcode( $args ) {
			if( empty( $args['id'] ) )
				return null;
			
			$task_id = ( int ) $args['id'];
			
			if( 0 == $task_id )
				return null;
					
			/** On récupère la tâche */
			$task = $this->show( $task_id );
			$task = $this->get_task_information( $task );
							
			ob_start();
			?><div class="wpeo-project-wrap <?php echo !empty( $custom_class ) ? $custom_class : ''; ?>">	<?php 
			$this->render_task( $task );
			?></div><?php 
			return ob_get_clean();
		}
	
		public function callback_my_account_menu( $content ) {
			require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'frontend/account', 'menu' ) );
		}
		
		public function callback_my_account_content( $output, $dashboard_part ) {
			if( 'my-task' === $dashboard_part ) {
				
				/** On récupère l'id du client */
				$customer_id = wps_customer_ctr::get_customer_id_by_author_id( get_current_user_id() );
				
				$wps_orders_mdl = new wps_orders_mdl();
				$list_order 	= $wps_orders_mdl->get_customer_orders( get_current_user_id() );
				
				if( !empty( $list_order ) ) {
					foreach( $list_order as $order_index => $order ) {
						$list_task = $this->index( array( 'post_parent' => $order->ID ) );
							
						if( !empty( $list_task ) ) {
							foreach( $list_task as $task_index => $task ) {
								$list_task[$task_index] = $this->get_task_information( $list_task[$task_index] );
							}
						}
						
						$list_order[$order_index]->task = $list_task;
					}
				}
				
				$list_task = $this->index( array( 'post_parent' => $customer_id ) );
				
				if( !empty( $list_task ) ) {
					foreach( $list_task as $index => $task ) {
						$list_task[$index] = $this->get_task_information( $list_task[$index] );
					}
				}
										
				ob_start();
				require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'frontend/account', 'ask-task' ) );
				?><div class="wpeo-project-account"><?php
				require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'frontend/account', 'list', 'task' ) );
				require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'frontend', 'window' ) );
				$output = ob_get_clean();
				?></div><?php
			}
			
			return $output;
		}
	
		/**
		 * Récupères toutes les informations de la tâche avec la méthode get_task_information et
		 * apelle le template task.php
		 * 
		 * @param task_model_01 $task L'objet tâche
		 * @param bool $need_information Si besoin d'appeller la méthode get_task_information
		 * @return void
		 */
		public function render_task( $task, $need_information = true ) {
			if ( $need_information )
			$task = $this->get_task_information( $task );
			require( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'task' ) );
		}
		
		public function render_task_frontend( $task, $need_information = true ) {
			if ( $need_information )
				$task = $this->get_task_information( $task );
			require( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'frontend', 'task' ) );
		}
	
		/**
		 * Quand WPShop est activé, on récupères tous les clients et on les affiches dans un selct
		 * pour ensuite effecter un choosen dessus. 
		 */
		public function render_wpshop_filter() {
			$list_customer = $this->get_all_customer( 'draft' );
			$list_customer = array_merge( $list_customer, $this->get_all_customer( 'publish' ) );
			
			require( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'wpshop', 'filter' ) );
		}
		
		private function get_all_customer( $post_status = 'publish' ) {
			global $wpdb;
		
			$query = $wpdb->prepare(
					"SELECT p.*, u.user_login, u.display_name, u.user_email FROM {$wpdb->posts} as p
					JOIN {$wpdb->users} as u ON u.ID=p.post_author
					WHERE p.post_type = %s AND
					p.post_status = %s",
			'wpshop_customers',
					$post_status
			);
		
			$list_customer 	= $wpdb->get_results( $query );
		
			return $list_customer;
		}
		
		/**
		 * Compiles le temps des commentaires dans les points pour mêttre à jour le temps dans les
		 * points puis ensuites dans les tâches.
		 * 
		 * @param int $task_id L'id de la tâche
		 */
		public function compile_time( $task_id ) {
			global $point_time_controller;
			global $point_controller;
			
			$total_time_elapsed = 0;
			
			$task = $this->show( $task_id );
			
			if ( !empty( $task ) ) {
				$task->point = $this->get_point( $task->option['task_info']['order_point_id'] );
				
				if ( !empty( $task->point ) ) {
					foreach ( $task->point as $point ) {
						$point_time_elapsed = 0;
						$comment_in_point = $point_time_controller->get_all_comment_in_point( $task->id, $point->id );
						if ( !empty( $comment_in_point ) ) {
							foreach( $comment_in_point as $comment ) {
								$point_time_elapsed += $comment->option['time_info']['elapsed'];
							}
						}
						$point->option['time_info']['elapsed'] = $point_time_elapsed;
						$point_controller->update( $point );
						$total_time_elapsed += $point_time_elapsed;
					}
				}
				
				$task->option['time_info']['elapsed'] = $total_time_elapsed;
				$this->update( $task );
				
			}
			return $task;
		}
	}

	global $task_controller;
	$task_controller = new task_controller_01();
}
?>
