<?php

class wpeo_task_ajax_ctr_01 {
	public function __construct() {
		add_action('wp_ajax_create_task', array($this, 'ajax_create_task'));
		add_action('wp_ajax_edit_task', array($this, 'ajax_edit_task'));
		add_action('wp_ajax_delete_task', array($this, 'ajax_delete_task'));
		
		add_action('wp_ajax_view_task_setting', array(&$this, 'ajax_view_task_setting'));
		
		add_action('wp_ajax_archive_task', array(&$this, 'ajax_archive_task'));
		add_action('wp_ajax_load_archive_task', array(&$this, 'ajax_load_archive_task'));
	
		add_action('wp_ajax_export_task', array(&$this, 'ajax_export_task'));
		add_action('wp_ajax_export_all_task', array($this, 'ajax_export_all_task'));
		
		/** Additional informations */
		add_action( 'wp_ajax_load_dashboard_task', array( &$this, 'ajax_load_dashboard_task' ) );
		
		add_action( 'wp_ajax_view_task_tag', array( &$this, 'ajax_view_task_tag' ) );
		add_action( 'wp_ajax_edit_task_tag', array( &$this, 'ajax_edit_task_tag' ) );
	}
	
	public function ajax_create_task() {
		global $task_ctr_01;
		
		$data = array(
			'title' => __( 'New task', 'wpeo-task' ),
		);
		
		$data['option']['user_info']['owner_id'] = get_current_user_id();
		
		if( !empty( $_POST['parent_id'] ) )
			$data['parent_id'] = $_POST['parent_id'];
		
		$task = $task_ctr_01->create( $data );
		$task->tag = $task_ctr_01->get_tag( array() );
		$task->my_task = 'wpeo-my-task';
		$task->affected_task = '';		
		
		$list_user = $task_ctr_01->get_list_user_with_avatar();

		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'task' ) );
		$template = ob_get_clean();
		
		wp_die( $template );
	}
	
	public function ajax_edit_task() {
		header( 'Content-Type: application/json' );
		
		global $task_ctr_01;
				
		$object = $task_ctr_01->update( $_POST['task'] );
		wp_die( json_encode ( $object ) );
	}

	public function ajax_delete_task() {
		global $task_ctr_01;
		$task_ctr_01->delete( $_POST['id'] );
		wp_die();
	}
	
	public function ajax_view_task_setting() {
		require_once( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'task', 'setting' ) );
		wp_die();
	}

	public function ajax_archive_task() {
		global $task_ctr_01;
		global $tag_controller_01;
		$task = $task_ctr_01->show( $_POST['id'] );
		
		$term = get_term_by( 'slug', 'archive', $tag_controller_01->get_taxonomy() );
		
		if( empty( $term ) ) {
			$term = wp_set_object_terms( $_POST['id'], 'archive', $tag_controller_01->get_taxonomy() );
			$task->taxonomy[$tag_controller_01->get_taxonomy()][] = $term[0];
		}
		else {
			$task->taxonomy[$tag_controller_01->get_taxonomy()][] = $term->term_id;
		}
		
		
		$task_ctr_01->update( $task );
		wp_die();
	}
	
	public function ajax_load_archive_task() {
		header( 'Content-Type: application/json' );
		$response = array();
		
		global $task_ctr_01;
		$array_task = $task_ctr_01->index(array('post_parent' => 0, 'post_status' => 'archive'));

		$current_user_id = get_current_user_id();
		$list_user = $task_ctr_01->get_list_user_with_avatar();
		
		if(!empty($array_task)) {
			foreach($array_task as $key => $task) {
				ob_start();
				require(wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'task'));
				$response[$key] = ob_get_clean();
			}
		}
		
		wp_die(json_encode($response));
	}
	
	public function ajax_export_task() {
		global $task_ctr_01;
		$task 			= $task_ctr_01->show( $_POST['id'] );
		$task->point 	= $task_ctr_01->get_point( $task->option['task_info']['order_point_id'] );
		$name_file		= $task->slug . current_time( 'timestamp' ) . '.txt';
		$path_file		= WPEOMTM_TASK_EXPORT_DIR . $name_file;
		$url_to_file	= WPEOMTM_TASK_EXPORT_URL . $name_file;
		$content_file	= $task->id . ' - ' . $task->title . "
				
";
		
		$point_in_work 		= false;
		$point_completed	= false;
		
		if(!empty($task->point)) {
			foreach($task->point as $point) {
				if($point->option['point_info']['completed']) {
					if(!$point_completed) {
						$content_file .= __('Completed', 'wpeotask-i18n') . '
';
						$point_completed = true;
					}
					$content_file .= '    ' . $point->id . ' - ' . $point->content . "
";
				}
			}
			
			foreach($task->point as $point) {
				if(!$point->option['point_info']['completed']) {
					if(!$point_in_work) {
						$content_file .= __('In Progress', 'wpeotask-i18n') . '
';
						$point_in_work = true;
					}
					$content_file .= '    ' . $point->id . ' - ' . $point->content . "
";
				}
			}
		}
				
		$fp = fopen( $path_file, 'w' );
		fputs( $fp, $content_file );
		fclose( $fp );
		wp_die($url_to_file);
	}

	public function ajax_export_all_task() {
		global $task_ctr_01;
		
		$name_file		= '';
		$content_file	= '';
		
		if(!empty($_POST['array_task_id'])) {
			foreach($_POST['array_task_id'] as $task_id) {
				$task 			= $task_ctr_01->show($task_id);
				$task->point 	= $task_ctr_01->get_point( $task->option['task_info']['order_point_id'] );
				$point_in_work = false;
				$point_completed = false;
				$name_file .= $task_id . '_';			
				$content_file .= $task_id . ' - ' . $task->title . "

";
				if(!empty($task->point)) {
					foreach($task->point as $point) {
						if($point->option['point_info']['completed']) {
							if(!$point_completed) {
								$content_file .= __('Completed', 'wpeotask-i18n') . '
';
								$point_completed = true;
							}
							$content_file .= '    ' . $point->id . ' - ' . $point->content . "
";
						}
					}
			
					foreach($task->point as $point) {
						if(!$point->option['point_info']['completed']) {
							if(!$point_in_work) {
								$content_file .= __('In Progress', 'wpeotask-i18n') . '
';
								$point_in_work = true;
							}
							$content_file .= '    ' . $point->id . ' - ' . $point->content . "
";
						}
					}
				}
				
				$content_file .= "
						
";
			}
			$name_file .= current_time('timestamp') . '.txt';
		}
		
		$path_file		= WPEOMTM_TASK_EXPORT_DIR . $name_file;
		$url_to_file	= WPEOMTM_TASK_EXPORT_URL . $name_file;
		
		$fp = fopen( $path_file, 'w' );
		fputs( $fp, $content_file );
		fclose( $fp );
		wp_die($url_to_file);
	}

	public function ajax_load_dashboard_task() {
		global $task_ctr_01;
		global $user_controller_01;
				
		$task 			= $task_ctr_01->show( ( int ) $_POST['task_id'] );
		$task->point	= $task_ctr_01->get_point( $task->option['task_info']['order_point_id'] );
		$owner_user 	= $user_controller_01->show( $task->option['user_info']['owner_id'] );
		
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'window', 'dashboard-task' ) );
		
		wp_die();
	}
	
	public function ajax_view_task_tag() {
		global $task_ctr_01;
		global $tag_controller_01;
		
		$object = $task_ctr_01->show( ( int ) $_POST['object_id'] );
		
		$list_tag 			= $tag_controller_01->index();
		$list_tag_in_object = array();
		$list_tag_id		= array();
				
		if ( !empty( $object->taxonomy ) && !empty( $object->taxonomy['wpeo_tag'] ) ) {
			foreach( $object->taxonomy['wpeo_tag'] as $tag_id ) {
				$list_tag_in_object[] 	= $tag_controller_01->show( $tag_id );
				$list_tag_id[] 			= $tag_id;
			}
		}
		
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_TAG_DIR, WPEOMTM_TAG_TEMPLATES_MAIN_DIR, 'backend', 'display', 'tag-selected' ) );
		
		wp_die();
	}
	
	public function ajax_edit_task_tag() {
		global $task_ctr_01;
		
		$task = $task_ctr_01->show( $_POST['object_id'] );
		
		$selected = ( $_POST['selected'] == 'true' ) ? true : false;
		
		if( $task != null ) {
			if( $selected ) {
				$task->taxonomy['wpeo_tag'][] = ( int ) $_POST['tag_id'];
			}
			else {
				$key = array_search( ( int ) $_POST['tag_id'], $task->taxonomy['wpeo_tag'] );
								
				if( $key > -1 ) 
					unset( $task->taxonomy['wpeo_tag'][$key] );
			}
			
			
			$task_ctr_01->update( $task );
		}
		
		wp_die();
	}
}