<?php

/**
 * Main controller file for WP logs module
 *
 * @author Eoxia development team <dev@eoxia.com>
 * @version 1.0
 * @package wpeolog
 * @subpackage controller
 */

/**
 * Main controller class for WP logs module
 *
 * @author Eoxia development team <dev@eoxia.com>
 * @version 1.0
 * @package wpeolog
 * @subpackage controller
 */

if ( !class_exists( "wpeologs_ctr" ) ) {

	/**
	 *
	 *
	 * @param string $service_name Le nom du service
	 * @param array $args
	 * @param int $criticality
	 */
	function eo_log( $service_name, $args, $criticality = 0 ) {
		wpeologs_ctr::log_datas_in_files( $service_name, $args, $criticality );
	}

	class wpeologs_ctr {
		/**	Define the var containing directory name to logs	*/
		var $log_directory;

		static $file_separator = "!#logsep#!";

		public $array_criticality = array();

		/**
		 * construct - Initialize array criticality, add filter for content save pre and admin_enqueue_scripts
		 *
		 * @return void
		 */
		public function __construct() {
			add_action( 'admin_menu', array( &$this, 'admin_menu' ) );

			// Service action
			add_action( 'admin_post_add', 'wpeo_log::add' );
			add_action( 'admin_post_edit_service', array( $this, 'edit_service' ) );
			add_action( 'admin_post_to_trash', array( $this, 'to_trash' ) );
			add_action( 'admin_post_file_to_trash', array( $this, 'file_to_trash' ) );
// 			$this->init_array_criticality();

// 			/**	Filter action on save post before saving, in order to log saved datas	*/
// 			 add_filter( 'content_save_pre', array( &$this, 'content_logger' ) );

// 			/**	Call administration style definition	*/
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
// 			/** When switch theme */
// 			add_action( 'switch_theme', array( &$this, 'switch_theme' ) );

// 			add_action( 'activate_plugin', array( &$this, 'activated_plugin' ), 10, 2 );
// 			add_action( 'deactivate_plugin', array( &$this, 'deactivated_plugin' ), 10, 2 );

		}

		/**
		 * Ajoutes le sous menu "Logs" au menu Tools de WordPress.
		 *
		 * @return void
		 */
		public function admin_menu() {
			add_submenu_page( 'tools.php', __( 'Logs', 'wpeolog-i18n' ), __( 'Logs', 'wpeolog-i18n' ), 'manage_options', 'wpeo-log-page', array( &$this, 'render_add_submenu_page' ) );
		}

		/**
		 * Le rendu du sous menu "Logs". Apelle le template main.php
		 */
		public function render_add_submenu_page() {

			$upload_dir = wp_upload_dir();
			$dir_file = $upload_dir['basedir'] . '/wpeolog/';

			$array_size_format = $this->get_array_size_format();
			$array_file_rotate_dropdown = array( 'on' => __( 'On', 'wpeolog-i18n' ), 'off' => __( 'Off', 'wpeolog-i18n' ) );
			$array_service = get_option( '_wpeo_log_settings' );
			$array_service = json_decode( $array_service, true );

			if ( !empty( $array_service ) ) {
				foreach ( $array_service as &$service ) {
					$service['error'] = $this->open_log( $service['name'] . '-error' );
					$service['warning'] = $this->open_log( $service['name'] . '-warning' );
				}
			}
			unset( $service );

			$count_service_active = 0;
			$count_service_desactive = 0;

			$page_transient = get_transient( 'log_message' );
			if ( !empty( $page_transient ) ) {
				delete_transient( 'log_message' );
				$page_transient = json_decode( $page_transient, true );
			}

			$array_data = $this->check_page();

			$count_warning = $array_data['count_warning'];
			$count_error = $array_data['count_error'];
			$count_info = count( $array_data['data']['data'] );

			$file = $array_data['data']['data'];
			$list_archive_file = $array_data['list_archive_file'];

			require_once( wpeo_template_01::get_template_part( WPEO_LOGS_DIR, WPEO_LOGS_TEMPLATES_MAIN_DIR, 'backend', 'main' ) );
		}

		private function check_page() {
			if ( !empty( $_GET['action'] ) && 'view' == $_GET['action'] && isset( $_GET['service_id'] ) ) {
				$service = self::get_service_by_id( $_GET['service_id'] );

				if( $service == null )
					return null;

				$service_name = $service['name'];

				if ( !empty( $_GET['type'] ) ) {
					$service_name .= '-' . $_GET['type'];
				}

				// Tous les fichiers
				$list_archive_file = $this->get_archive_file( $service_name );

				if( !empty( $_GET['key'] ) ) {
					$service_name .= '_' . $_GET['key'];
				}

				$count_warning = $this->open_log( $service['name'] . '-warning' );
				$count_error = $this->open_log( $service['name'] . '-error' );

				$array_data = $this->open_log( $service_name );

				return array( 'data' => $array_data, 'list_archive_file' => $list_archive_file, 'count_warning' => $count_warning['count'], 'count_error' => $count_error['count'] );
			}
		}

		public function admin_enqueue_scripts() {
			wp_register_script( 'wps_statistics_js_chart', WPEO_LOGS_URL . '/asset/js/chart.js');
			wp_enqueue_script( 'wps_statistics_js_chart' );
		}

		private function open_log( $service_name ) {
			$upload_dir = wp_upload_dir();
			$dir_file = $upload_dir['basedir'] . '/wpeolog/' . $service_name . '.csv';

			if ( file_exists( $dir_file ) ) {
				$file = file( $dir_file );

				// Remove the first case empty
				array_shift( $file );

				foreach( $file as &$data ) {
					$data = explode( wpeo_log::$file_separator, $data );
				}

				return array( 'data' => $file, 'count' => count( $file ) );
			}
			else {
				return array( 'data' => null, 'count' => 0 );
			}
		}

		private function get_archive_file( $name ) {
			// Get archive
			$upload_dir = wp_upload_dir();
			$dir_file = $upload_dir['basedir'] . '/wpeolog/';

			$array_glob_file = glob( $dir_file . $name . '*.csv' );

			foreach( $array_glob_file as &$glob_file ) {
				$glob_file = explode('/', $glob_file);
				$glob_file = $glob_file[count($glob_file) - 1];
			}

			return $array_glob_file;
		}

		/**
		* init_array_criticality
		*/
		private function init_array_criticality() {
			/** init array */
			$this->array_criticality[0] = array(
				'dashicons' => 'info',
				'message' 	=> __('Information', 'wpeolog-i18n')
			);

			$this->array_criticality[1] = array(
				'dashicons' => 'carrot',
				'message' 	=> __('Warning', 'wpeolog-i18n')
			);

			$this->array_criticality[2] = array(
				'dashicons' => 'no',
				'message' 	=> __('Critical', 'wpeolog-i18n')
			);
		}

		/**
		 * DEBUG LOG - Save a file on the server with content for loggin different action sended
		 *
		 * @param string $service (Name module or post type)
		 * @param array $array_message ('object_id', 'message')
		 * @param int $criticality The message crit rate (0-2)
		 */
		public static function log_datas_in_files( $name, $array_message, $criticality ) {
			$upload_dir = wp_upload_dir();

			$backtrace = debug_backtrace();

			// On récupère le service
			$service = self::get_service_by_name( $name );

			if( $service == null ) {
			/** Créer le service s'il n'existe pas */
				$service = self::add( $name );
			}

			wp_mkdir_p( $upload_dir[ 'basedir' ] . '/wpeolog/' );

			if( $service == null )
				return null;

			$message = "
	";
			$message .= current_time('mysql', 0) . self::$file_separator;
			$message .= get_current_user_id() . self::$file_separator;
			$message .= '"' . $name . '"' . self::$file_separator;
			$message .= !empty( $array_message['object_id'] ) ? $array_message['object_id'] : 'Not found' . self::$file_separator;

			// For post type
			if(!empty($array_message['previous_element'])) {
				$message .= '"' . base64_encode(serialize($array_message['previous_element'])) . '"' . self::$file_separator;
				$message .= '"' . base64_encode(serialize($array_message['previous_element_metas'])) . '"' . self::$file_separator;
			}

			if(!empty($array_message['message'])) {
				$message .= '"' . $array_message['message'] . '"' . self::$file_separator;
			}
			$message .= $criticality . self::$file_separator . $name . self::$file_separator;

			if ( !empty( $backtrace ) ) {
				foreach ( $backtrace as $t ) {
					$message .= ( !empty( $t['file'] ) ? $t['file'] : '' ) . ' line ' . ( !empty( $t['line'] ) ? $t['line'] : '' ) . ' function ' . $t['function'] . '()<br />';
				}
			}

			self::check_need_rotate( $service, $name . '-info', $message);

			$fp = fopen( $upload_dir[ 'basedir' ] . '/wpeolog/' . $name . '-info.csv', 'a');
			fwrite($fp, $message);
			fclose($fp);

			if( 2 <= $criticality ) {
				self::check_need_rotate( $service, $name . '-error', $message);

				$fp = fopen( $upload_dir[ 'basedir' ] . '/wpeolog/' . $name . '-error.csv', 'a');
				fwrite($fp, $message);
				fclose($fp);
			}
			else if( 1 == $criticality ) {
				self::check_need_rotate( $service, $name . '-warning', $message);

				$fp = fopen( $upload_dir[ 'basedir' ] . '/wpeolog/' . $name . '-warning.csv', 'a');
				fwrite( $fp, $message );
				fclose( $fp );
			}
		}

		/**
		* check_need_rotate  Checks if the file exceeds the maximum size
		*
		* @param string $file_link The file path to write
		*/
		public static function check_need_rotate( $service, $name, $message ) {
			$upload_dir = wp_upload_dir();

			$max_size = $service['size'];

			$file_link = $upload_dir[ 'basedir' ] . '/wpeolog/' . $name . '.csv';

			if( file_exists( $file_link ) ) {
				// Get full message
				$message = file_get_contents( $file_link ) . $message;

				$file_size = filesize( $file_link );

				if($file_size >= $max_size)
					self::rename_current_file( $service, $name, $file_link );
				else if(strlen($message) >= $max_size)
					self::rename_current_file( $service, $name, $file_link );

				return $file_link;
			}

		}

		/**
		 * rename_current_file - Rename the current file
		 *
		 * @param string $service
		 * @param string $file_link
		 */
		public static function rename_current_file( $service, $name, $file_link ) {
				$upload_dir = wp_upload_dir();

				$number_archive = $service['number'];

				if( file_exists ( $file_link ) ) {
					$file_explode = explode('.csv', $file_link);
					$get_all_file = glob($file_explode[0] . '*.csv');
					array_shift($get_all_file);
					arsort($get_all_file);

					foreach($get_all_file as $full_file) {
						$file = explode('/', $full_file);
						$file_name = $file[count($file) - 1];
						$file_name = explode('.', $file_name);

						$file_name[0]++;
						rename($full_file, $upload_dir[ 'basedir' ] . '/wpeolog/' . $file_name[0] . '.csv');

						// Check if not execeed the number archive
						$count = explode('_', $file_name[0]);

						if($count[1] > $number_archive && file_exists($upload_dir[ 'basedir' ] . '/wpeolog/' . $file_name[0] . '.csv')) {
							unlink($upload_dir[ 'basedir' ] . '/wpeolog/' . $file_name[0] . '.csv');
						}
					}
					rename( $file_link, $file_explode[0] . '_1.csv' );
				}
		}

		/**
		 * Récupères le service selon son nom.
		 *
		 * @param string $name Le nom du service
		 * @return array | null
		 */
		public static function get_service_by_name( $name ) {
			$array_service = get_option( '_wpeo_log_settings', array() );

			$getted_service = null;

			if ( !empty( $array_service ) ) {
				$array_service = !is_array( $array_service ) ? json_decode( $array_service, true ) : $array_service;

				foreach ( $array_service as $service ) {
					if( $service['name'] == $name ) {
						$getted_service = $service;
						break;
					}
				}
			}

			return $getted_service;
		}

		public static function get_service_by_id( $id ) {
			$array_service = get_option( '_wpeo_log_settings', array() );

			$getted_service = null;

			if ( !empty( $array_service ) ) {
				$array_service = json_decode( $array_service, true );

				foreach ( $array_service as $key => $service ) {
					if( $key == $id ) {
						$getted_service = $service;
						break;
					}
				}
			}

			return $getted_service;
		}

		/**
		 * Log informations for setted type when post is saved
		 */
		function content_logger( $content ) {
			remove_filter('content_save_pre', array( &$this, 'content_logger' ) );
			if ( !empty( $_POST ) && !empty( $_POST[ 'post_type' ] ) && !empty($this->wpeolog_settings['my_services']) && !empty($this->wpeolog_settings['my_services'][$_POST['post_type']]) && $this->wpeolog_settings['my_services'][$_POST['post_type']]['service_active']) {
				 $previous_element = get_post( $_POST[ 'post_ID' ] );
				 $previous_element_metas = get_post_meta( $_POST[ 'post_ID' ] );

				if ( !empty( $previous_element ) ) {
					wpeolog_ctr::log_datas_in_files($_POST['post_type'],
						array('object_id' => $_POST['post_ID'],
								'previous_element' => $previous_element,
								'previous_element_metas' => $previous_element_metas ),
								$_POST['post_type'], WPEO_CRITICALITY_INFORMATIONS );
				}
			}

			return $content;
		}

		/**
		 * install_service - insert sql to option _wpeo_log_settings
		 */
		public function install_service() {
// 			$option_name = "_wpeo_log_settings";
// 			$option_value = 'a:2:{s:11:"my_services";a:4:{s:4:"post";a:6:{s:14:"service_active";i:1;s:12:"service_name";s:4:"post";s:12:"service_size";i:8192;s:19:"service_size_format";s:2:"ko";s:12:"service_file";s:1:"5";s:14:"service_rotate";i:1;}s:4:"page";a:6:{s:14:"service_active";i:1;s:12:"service_name";s:4:"page";s:12:"service_size";i:8192;s:19:"service_size_format";s:2:"ko";s:12:"service_file";s:1:"5";s:14:"service_rotate";i:1;}s:6:"themes";a:6:{s:14:"service_active";i:1;s:12:"service_name";s:6:"themes";s:12:"service_size";i:8192;s:19:"service_size_format";s:2:"ko";s:12:"service_file";s:1:"5";s:14:"service_rotate";i:1;}s:7:"plugins";a:6:{s:14:"service_active";i:1;s:12:"service_name";s:7:"plugins";s:12:"service_size";i:8192;s:19:"service_size_format";s:2:"ko";s:12:"service_file";s:1:"5";s:14:"service_rotate";i:1;}}s:9:"file_size";i:0;}';

// 			// Insert in wp_options
// 			$option = get_option($option_name);

// 			if(empty($option))
// 				update_option($option_name, unserialize($option_value));
		}

		/**
		 * switch_theme - When switch theme
		 * @param string $name_theme - The name of theme
		 */
		public function switch_theme($name_theme) {
// 			$i = self::new_instance();
// 			if(!empty($i->wpeolog_settings['my_services']["themes"]) && $i->wpeolog_settings['my_services']["themes"]['service_active'])
// 				self::log_datas_in_files("themes", array("object_id" => $name_theme, "message" => __('The theme ' . $name_theme . ' is activated')), 0);
		}

		/**
		 * activate_plugins_loaded - call log_datas_in_files for all plugins activate
		 */
// 		public function activated_plugin($plugin, $network_activation) {
// 			$i = self::new_instance();
// 			if(!empty($i->wpeolog_settings['my_services']["plugins"]) && $i->wpeolog_settings['my_services']["plugins"]['service_active'])
// 				self::log_datas_in_files("plugins", array("object_id" => $plugin, "message" => __('The plugin ' . $plugin . ' is activated')), 0);
// 		}

// 		public function deactivated_plugin($plugin, $network_activation) {
// 			$i = self::new_instance();
// 			if(!empty($i->wpeolog_settings['my_services']["plugins"]) && $i->wpeolog_settings['my_services']["plugins"]['service_active'])
// 				self::log_datas_in_files("plugins", array("object_id" => $plugin, "message" => __('The plugin ' . $plugin . ' is deactivated')), 0);
// 		}

		/**
		 * convert to - Convert format to "oc" or deconvert
		 *
		 * @param float $input
		 * @param string $format
		 * @param boolean $convert
		 * @return float|number
		 */
		function convert_to($input, $format, $convert = true) {
			if($format == 'oc')
				return $input;

			$multiple = 0;

			if($format == 'ko')
				$multiple = 1024;
			else if($format == 'mo')
				$multiple = 1048576;
			else if($format == 'go')
				$multiple = 1073741824;

			if($convert)
				return $input * $multiple;
			else
				return $input / $multiple;
		}

		/**
		 * get_array_size_format
		 *
		 * @return multitype:string
		 */
		function get_array_size_format() {
			return array('oc' => 'Octets', 'ko' => 'Ko', 'mo' => 'Mo', 'go' => 'Go');
		}

		/**
		 * Crée un service par défaut et l'ajoutes au tableau JSON _wpeo_log_settings.
		 * Renvoie un message de type updated en transient pour afficher qu'un
		 * nouveau service à été crée.
		 *
		 * @param string $name Le nom du service
		 * @return void
		 */
		public static function add( $name ) {
			$data_service = array(
					'active' 		=> true,
					'name'			=> !empty( $name ) ? $name : 'new_log',
					'size' 			=> '1024',
					'format' 		=> 'ko',
					'rotate'		=> false,
					'number' 		=> 0,
					'created_date'	=> current_time( 'mysql' ),
			);

			$array_current_settings = get_option( '_wpeo_log_settings' );
			if ( !empty( $array_current_settings ) ) {
				$array_current_settings = json_decode( $array_current_settings, true );
			}
			else {
				$array_current_settings = array();
			}

			$array_current_settings[] = $data_service;
			$success = update_option( '_wpeo_log_settings', json_encode( $array_current_settings ) );

			if ( $success ) {
				set_transient( 'log_message', json_encode( array( 'type' => 'updated', 'message' => __( 'A new service has been created!', 'wpeolog-i18n' ) ) ) );
			}

			if ( !empty( $name ) ) {
				return $data_service;
			}
			else {
				wp_safe_redirect( wp_get_referer() );
				die();
			}
		}

		public function edit_service() {
			if ( empty( $_POST['service'] ) ) {
				set_transient( 'log_message', json_encode( array( 'type' => 'error', 'message' => __( 'Invalid data to update service' ), 'wpeolog-i18n' ) ) );
				wp_safe_redirect( wp_get_referer() );
				die();
			}

			foreach( $_POST['service'] as &$service ) {
				if( !ctype_digit( $service['size'] ) || !ctype_digit( $service['number'] ) ) {
					set_transient( 'log_message', json_encode( array( 'type' => 'error', 'message' => __( 'Invalid data to update service' ), 'wpeolog-i18n' ) ) );
					wp_safe_redirect( wp_get_referer() );
					die();
				}

				$service['size'] = $this->convert_to( $service['size'], $service['format'] );
			}

			unset( $service );


			$array_current_setting = get_option( '_wpeo_log_settings' );
			$array_current_setting = json_decode( $array_current_setting, true );

			$array_current_setting = array_replace( $array_current_setting, $_POST['service'] );

			$success = update_option( '_wpeo_log_settings', json_encode( $array_current_setting ) );

			if( $success ) {
				set_transient( 'log_message', json_encode( array( 'type' => 'updated', 'message' => __( 'The services has been updated!', 'wpeolog-i18n' ) ) ) );
			}

			wp_safe_redirect( wp_get_referer() );
			die();
		}

		public function to_trash() {
			if ( !isset( $_GET['_wpnonce'] ) || !wp_verify_nonce( $_GET['_wpnonce'], 'to_trash_' . $_GET['service_id'] ) ) {
				wp_safe_redirect( wp_get_referer() );
				die();
			}

			$array_current_setting = get_option( '_wpeo_log_settings' );
			$array_current_setting = json_decode( $array_current_setting, true );

			if ( !empty( $array_current_setting[$_GET['service_id']] ) ) {
				unset( $array_current_setting[$_GET['service_id']] );
				$success = update_option( '_wpeo_log_settings', json_encode( $array_current_setting ) );

				if( $success ) {
					set_transient( 'log_message', json_encode( array( 'type' => 'updated', 'message' => __( sprintf( 'The service %d has been deleted!', $_GET['service_id'] ), 'wpeolog-i18n' ) ) ) );
				}
			}
			else {
				set_transient( 'log_message', json_encode( array( 'type' => 'error', 'message' => __( sprintf( 'The service %d is invalid!', $_GET['service_id'] ), 'wpeolog-i18n' ) ) ) );
			}

			wp_safe_redirect( wp_get_referer() );
			die();
		}

		/**
		 * Supprimes un fichier par le biais de la fonction unlink
		 *
		 * @param $_GET['file_name'] Le nom du fichier à supprimer
		 * @return void
		 */
		public function file_to_trash() {
			$upload_dir = wp_upload_dir();
			$dir_file = $upload_dir['basedir'] . '/wpeolog/';

			$success = unlink( $dir_file . $_GET['file_name'] );
			if ( $success )
				set_transient( 'log_message', json_encode( array( 'type' => 'updated', 'message' => __( 'The file has been deleted!', 'wpeolog-i18n' ) ) ) );
			wp_safe_redirect( wp_get_referer() );
			die();
		}
	}
}

?>