<?php

if ( !defined( 'ABSPATH' ) ) exit;

class point_action_01 {
	public function __construct() {
		/** Point */
		add_action( 'wp_ajax_create_point', array( &$this, 'ajax_create_point' ) );		
		add_action( 'wp_ajax_delete_point', array( &$this, 'ajax_delete_point' ) );
		add_action( 'wp_ajax_edit_point', array( &$this, 'ajax_edit_point' ) );
		add_action( 'wp_ajax_edit_order_point', array( &$this, 'ajax_edit_order_point' ) );
		
		/** Point time */
		add_action( 'wp_ajax_thickbox_point_time', array( &$this, 'ajax_thickbox_point_time' ) );
		add_action( 'wp_ajax_create_point_time', array( &$this, 'ajax_create_point_time' ) );
		add_action( 'wp_ajax_create_point_time_client', array( &$this, 'ajax_create_point_time_client' ) );
		add_action( 'wp_ajax_get_point_time', array( &$this, 'ajax_get_point_time' ) );
		add_action( 'wp_ajax_nopriv_get_point_time', array( &$this, 'ajax_get_point_time' ) );
		add_action( 'wp_ajax_delete_point_time', array( &$this, 'ajax_delete_point_time' ) );
		
		/** Dashboard */
		add_action( 'wp_ajax_load_dashboard_point', array( &$this, 'ajax_load_dashboard_point' ) );
		add_action( 'wp_ajax_load_frontend_dashboard_point', array( &$this, 'ajax_load_frontend_dashboard_point' ) );
		
		add_action( 'wp_ajax_send_point_to_task', array( &$this, 'ajax_send_point_to_task' ) );
		add_action( 'wp_ajax_load_last_comment', array( &$this, 'ajax_load_last_comment') );
	}
	
	/**
	 * Créer un point avec le status -34070 et assignes le à une tâche. Ensuite renvoie 
	 * le template backend-point. / Create an point with the status -34070 and assign it
	 * to a task. Then send the template backend-point.
	 * 
	 * @param string $_GET['_wpnonce'] Le code de sécurité crée par la fonction wp_create_nonce de 
	 * WordPress
	 * @param int $_POST['point']['post_id'] ID de la tâche / The task ID
	 * @param string $_POST['content'] Le contenu du point / The point content
	 * 
	 * @return string Le template d'un point / The template of point
	 */
	public function ajax_create_point() {
		$object_id = $_POST['point']['post_id'];
		if ( !is_int( $object_id ) )
			$object_id = intval( $object_id );
		
		wpeo_check_01::check( 'wpeo_nonce_create_point_' . $object_id );
		
		global $task_controller;
		global $point_controller;
		
		$_POST['point']['author_id'] = get_current_user_id();
		$_POST['point']['status'] = '-34070';
		$_POST['point']['date'] = current_time( 'mysql' );
		$point = $point_controller->create( $_POST['point'] );
		
		/** Add to the order point */
		$task = $task_controller->show( $object_id );
		$task->option['task_info']['order_point_id'][] = ( int ) $point->id;
		$task_controller->update( $task );
		
		/** Log la création du point / Log the creation of point */
		eo_log( 'wpeo_project',
			array(
				'object_id' => $object_id,
				'message' => sprintf( __( 'Create the point #%d with the content : %s for the task #%d', 'task-manager'), $point->id, $point->content, $object_id ),
			), 0 );
		
		$custom_class = 'wpeo-task-point-sortable';
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'point' ) );
			
		wp_send_json_success( array( 'template' => ob_get_clean() ) );	
	}
	
	/**
	 * Supprimes un point grâce à son point ID. Supprimes également le temps passé dans 
	 * la tâche en rapport avec ce point. Enlèves le point de order_point_id dans 
	 * la tâche et met à jours la tâche. / Delete an point by its point ID. Also delete 
	 * the elapsed time in the task in connection with this point. Take off the point 
	 * in order_point_id in the task and update this.
	 * 
	 * @param int $_POST['post_id'] ID de la tâche / The task ID
	 * @param int $_POST['point_id'] ID du point / The point ID
	 * 
	 * @return json task_mdl_01 Object
	 */
	public function ajax_delete_point() {
		wpeo_check_01::check( 'wpeo_nonce_delete_point_' . $_POST['point_id'] );
		
		global $task_controller;
		global $point_controller;
		
		$point 	= $point_controller->show( $_POST['point_id'] );
		$task 	= $point_controller->decrease_time( $_POST['point_id'] );
		
		if( ( $key = array_search( $_POST['point_id'], $task->option['task_info']['order_point_id'] ) ) !== false ) {
			unset( $task->option['task_info']['order_point_id'][$key] );
		}
				
		$task_controller->update( $task );
		
		/** Log la suppression du point / Log the deletion of point */
		eo_log( 'wpeo_project',
		array(
			'object_id' => $_POST['point_id'],
			'message' => sprintf( __( 'The point #%d was deleted for the task #%d. The elapsed time for this point was %d minute(s). The elapsed time for this task is now %d minute(s)', 'task-manager'), $point->id, $task->id, $point->option['time_info']['elapsed'], $task->option['time_info']['elapsed'] ),
		), 0 );
			
		wp_send_json_success( array( 'task' => $task ) );
	}
	
	/**
	 * Met à jour le contenu d'un point. / Update the content of point.
	 * 
	 * @param int $_POST['point']['post_id'] L'ID du post / The post ID
	 * @param int $_POST['point']['id'] L'ID du point / The point ID
	 * @param bool $_POST['point']['option']['point_info']['completed'] Le point est-il fait ? / The point is done ?
	 * @param string $_POST['point']['content'] Le contenu du point / The point content
	 * 
	 * @return void
	 */
	public function ajax_edit_point() {
		wpeo_check_01::check( 'wpeo_nonce_edit_point_' . $_POST['point']['id'] );
			global $point_controller;
			
			$point = $point_controller->show( $_POST['point']['id'] );			
			
			if( $_POST['point']['option']['point_info']['completed'] ) {
				$point->option['time_info']['completed_point'][get_current_user_id()][] = current_time( 'mysql' );
			}
			else {
				$point->option['time_info']['uncompleted_point'][get_current_user_id()][] = current_time( 'mysql' );
			}
			
			$_POST['point']['option']['time_info']['completed_point'] = $point->option['time_info']['completed_point'];
			$_POST['point']['option']['time_info']['uncompleted_point'] = $point->option['time_info']['uncompleted_point'];
						
			$point_controller->update( $_POST['point'] );
	
			eo_log( 'wpeo_project',
			array(
				'object_id' => $_POST['point']['id'],
				'message' => sprintf( __( 'The point #%d was updated with the content : %s and set to completed : %s', 'task-manager'), $_POST['point']['id'], $_POST['point']['content'], $_POST['point']['option']['point_info']['completed'] ),
			), 0 );
		
		wp_send_json_success( );
	}
	
	/**
	 * Met à jour la meta order_point_id d'une tâche / Update the meta order_point_id
	 * on a task.
	 * 
	 * @param int $_POST['object_id'] L'ID de la tâche / The task ID
	 * @param array $_POST['order_point_id'] Le tableau avec les id des points / The array of 
	 * id points
	 * 
	 * @return void
	 */
	public function ajax_edit_order_point() {
		global $task_controller;
		global $point_controller;
		
		$task = $task_controller->show( $_POST['object_id'] );
		$task->point = $task_controller->get_point( $task->option['task_info']['order_point_id'] ); 
		
		/** Get all completed point in the task for don't forget it in the order point id */
		foreach( $task->point as $point ) {
			if( $point->option['point_info']['completed'] )
				$_POST['order_point_id'][] = (int)$point->id;
		}
						
		$task->option['task_info']['order_point_id'] = $_POST['order_point_id'];
		$task_controller->update( $task );
		
		eo_log( 'wpeo_project',
		array(
			'object_id' => $_POST['object_id'],
			'message' => sprintf( __( 'The point order for the task #%d was reassigned : %s', 'task-manager'), $_POST['object_id'], implode( ',', $_POST['order_point_id'] ) ),
		), 0 );
		
		wp_die();
	}

	/**
	 * Charge le tableau de bord du point 
	 */
	public function ajax_load_dashboard_point() {
		wpeo_check_01::check( 'wpeo_nonce_load_dashboard_point_' . $_POST['point_id'] );
		
		global $task_controller;
		global $point_controller;
		global $point_time_controller;
		global $wp_project_user_controller;
		
		$task 				= $task_controller->show( $_POST['task_id'] );
		$point 				= $point_controller->show( $_POST['point_id'] );
		$point_user 		= $wp_project_user_controller->show( $point->author_id );
		$list_point_time 	= $point_time_controller->index( $task->id, array( 'parent' => $point->id, 'status' => -34070 ) );
		$list_user_in 		= array();
		
		if ( !empty( $list_point_time ) ) {
			foreach ( $list_point_time as $point_time ) {
				if ( empty( $list_user_in[$point_time->author_id] ) ) {
					$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
				}
			}
		}
		
		ob_start();
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'window', 'dashboard-point' ) );
		wp_send_json_success( array( 'template' => ob_get_clean() ) );
	}
	
	public function ajax_load_frontend_dashboard_point() {
		//wpeo_check_01::check( 'wpeo_nonce_load_dashboard_point_' . $_POST['point_id'] );
		
		global $point_time_controller;
		
		$list_point_time = $point_time_controller->index( $_POST['task_id'], array( 'parent' => $_POST['point_id'], 'status' => -34070 ) );
		$list_user_in 		= array();
		
		if ( !empty( $list_point_time ) ) {
			foreach ( $list_point_time as $point_time ) {
				if ( empty( $list_user_in[$point_time->author_id] ) ) {
					$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
				}
			}
		}
		
		ob_start();
		$show = true;
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'frontend', 'window' ) );
		wp_send_json_success( array( 'template' => ob_get_clean() ) );
	}
	
	public function ajax_create_point_time() {
		wpeo_check_01::check( 'wpeo_nonce_create_point_time_' . $_POST['point_time']['parent_id'] );
		
		global $point_time_controller;
		
		$response = array();
		
		$_POST['point_time']['date'] .= ' ' . current_time( 'h:i:s' );
		
		if ( !empty( $_POST['point_time_id'] ) ) {
			/** Edit the point */
			$point_time 									= $point_time_controller->show( $_POST['point_time_id'] );
			$point_time->option['time_info']['old_elapsed'] = $point_time->option['time_info']['elapsed'];
			$point_time->date 								= $_POST['point_time']['date'];
			$point_time->option['time_info']['elapsed'] 	= $_POST['point_time']['option']['time_info']['elapsed'];
			$point_time->content 							= $_POST['point_time']['content'];
			
			$response = $point_time_controller->update($point_time);			
		}
		else {
			/** Add the point */
			$_POST['point_time']['status'] = '-34070';
			
			$response 	= $point_time_controller->create( $_POST['point_time'] );
			$point_time = $point_time_controller->show( $response['point_time_id'] );
		}
		
		$list_user_in = array();
		
		if ( !empty( $point_time ) ) {
			$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
		}
		
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'point', 'time' ) );
		$response['template'] = ob_get_clean();
		
		wp_send_json_success( $response );
	}

	/**
	 * Create point time for WPShop client
	 */
	public function ajax_create_point_time_client() {
		if ( !wp_verify_nonce( $_POST['_wpnonce'], 'wpeo_nonce_create_point_time_frontend_' . $_POST['point_time']['parent_id'] ) ) {
			wp_send_json_error();
		}
		
		$edit = false;
		
		global $point_time_controller;
		
		if ( !empty( $_POST['point_time']['id'] ) ) {
			$point_time 			= $point_time_controller->show( $_POST['point_time']['id'] );
			$point_time->content 	= $_POST['point_time']['content'];
			
			$point_time_controller->update( $point_time );
			$edit = true;
// 			eo_log( 'wpeo_project',
// 			array(
// 			'object_id' => $_POST['point']['id'],
// 			'message' => sprintf( __( 'The point #%d was updated with the content : %s and set to completed : %s', 'task-manager'), $_POST['point']['id'], $_POST['point']['content'], $_POST['point']['option']['point_info']['completed'] ),
// 			), 0 );
		}
		else {
			$_POST['point_time']['status'] = '-34070';
			$_POST['point_time']['date'] = current_time( 'mysql' );
				
			$response 	= $point_time_controller->create( $_POST['point_time'] );
			$point_time = $point_time_controller->show( $response['point_time_id'] );
		}	

		$list_user_in 		= array();
		
		if ( empty( $list_user_in[$point_time->author_id] ) ) {
			$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
		}
			
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'frontend', 'point', 'time' ) );
		wp_send_json_success( array( 'template' => ob_get_clean(), 'edit' => $edit, ) );
	}
	
	public function ajax_get_point_time() {
		wpeo_check_01::check( 'wpeo_nonce_get_point_time_' . $_POST['point_time_id'] );
		
		if (  0 === is_int( ( int )$_POST['point_time_id'] ) )
			wp_send_json_error();
		else
			$point_time_id = $_POST['point_time_id'];
		
		global $point_time_controller;
		$point_time = $point_time_controller->show( $point_time_id );
		
		$date = explode( ' ', $point_time->date );
		
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'edit', 'point-time' ) );
		wp_send_json_success( array( 'point_time_id' => $point_time_id, 'template' => ob_get_clean() ) );
	}
	
	public function ajax_delete_point_time() {
		wpeo_check_01::check( 'wpeo_nonce_delete_point_time_' . $_POST['point_time_id'] );

		global $point_time_controller;
		
		$response = array();
		$task = $point_time_controller->delete( $_POST['point_time_id'] );
		
		wp_send_json_success( array( 'task' => $task ) );
	}

	public function ajax_send_point_to_task() {
		if( empty( $_POST['task_id'] ) )
			wp_send_json_error();
		
		global $task_controller;
		$current_task = $task_controller->show( $_POST['current_task_id'] );
		$task = $task_controller->show( $_POST['task_id'] );
		
		if( $current_task->id == 0 || $task->id == 0 || $current_task->status == 'trash' || $task->status == 'trash' )
			wp_send_json_error();
		
		if( ( $key = array_search( $_POST['point_id'], $current_task->option['task_info']['order_point_id'] ) ) !== false ) {
			unset( $current_task->option['task_info']['order_point_id'][$key] );
		}
		
		$task->option['task_info']['order_point_id'][] = $_POST['point_id'];
		
		$task_controller->update( $current_task );
		$task_controller->update( $task );
		
		global $point_controller;
		$point = $point_controller->show( $_POST['point_id'] );
		$point->post_id = $task->id;
		$point_controller->update( $point );
		$point_controller->send_comment_to( $current_task->id, $task->id, $_POST['point_id'] );
		
		$object_id = $task->id;
		
		$current_task = $task_controller->compile_time( $current_task->id );
		$task = $task_controller->compile_time( $task->id );

		$custom_class = ' wpeo-task-point-sortable ';
		
		ob_start();
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'point' ) );
		wp_send_json_success( 
			array( 
				'template' => ob_get_clean(), 
				'current_task_id' => $current_task->id, 
				'to_task_id' => $task->id, 
				'point_id' => $_POST['point_id'], 
				'current_task_time' => $current_task->option['time_info']['elapsed'], 
				'task_time' => $task->option['time_info']['elapsed'] 
			) 
		);
	}

	public function ajax_load_last_comment( $page ) {
		$_POST['page'] = !( empty( $page ) ) ? $page : $_POST['page'];
		
		if ( empty( $_POST['page'] ) )
			wp_send_json_error();
		
		global $point_time_controller;
		global $point_controller;
		
		$list_comment = $point_time_controller->get_all_comment( 'comment.comment_date', 'DESC', 5, $_POST['page'] - 1 );
		$count_comment = $point_time_controller->get_count_comment();
					
		$list_user_in = array();
			
		if ( !empty( $list_comment ) ) {
			foreach ( $list_comment as $comment ) {
				if ( empty( $list_user_in[$comment->author_id] ) ) {
					$list_user_in[$comment->author_id] = get_userdata( $comment->author_id );
				}
			}
		}
		
		$current_page = $_POST['page'];
		$number_paginate = ceil( $count_comment / 5 );
		
		ob_start();
		if ( !empty( $count_comment ) ) {
			require( wpeo_template_01::get_template_part( WPEOMTM_TASK_DIR, WPEOMTM_TASK_TEMPLATES_MAIN_DIR, 'backend', 'last', 'comment' ) );
		}
		if( !empty( $page ) ) {
			return ob_get_clean();
		}
		else {
			wp_send_json_success( array( 'template' => ob_get_clean() ) );
		}
	}
}

global $point_action;
$point_action = new point_action_01();