<?php

if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'point_controller_01' ) ) {
	class point_controller_01 extends comment_ctr_01 {
		protected $model_name 	= 'point_model_01';
		protected $meta_key		= 'wpeo_point';
		
		/** Défini la route par défaut permettant d'accèder aux temps pointés depuis WP Rest API  / Define the default route for accessing to point time from WP Rest API */
		protected $base = 'point';
		protected $version = '0.1';
		
		/**
		 * Constructeur qui inclus le modèle des points et également des les scripts 
		 * JS et CSS nécessaire pour le fonctionnement des points
		 * 
		 * @return void
		 */
		public function __construct() {
			parent::__construct();
			
			include_once( WPEOMTM_POINT_PATH . '/model/point.model.01.php' );
			
			add_action( 'admin_enqueue_scripts', array( &$this, 'callback_admin_enqueue_scripts' ), 1 );
			add_action( 'wp_enqueue_scripts', array( &$this, 'callback_wp_enqueue_scripts' ), 1 );
		}
		
		/** 
		 * WP HOOK - Initialize CSS and JS 
		 * 
		 * @return void
		 */
		public function callback_admin_enqueue_scripts() {
			wp_enqueue_script( 'wpeo-point-flextext-js', WPEOMTM_POINT_URL . '/asset/js/flextext.min.js', array("jquery",), WPEOMTM_POINT_VERSION );
			wp_enqueue_script( 'wpeo-point-backend-js', WPEOMTM_POINT_URL . '/asset/js/backend.js', array("jquery", "jquery-form", "jquery-ui-datepicker", "jquery-ui-sortable", "jquery-effects-core", "suggest" ), WPEOMTM_POINT_VERSION );
	
			//wp_register_style( 'wpeo-point-backend-css', WPEOMTM_POINT_URL . '/asset/css/backend.css', '', WPEOMTM_POINT_VERSION );
			//wp_enqueue_style( 'wpeo-point-backend-css' );
		}
		
		/**
		 * Importation du fichier JS pour le frontend
		 * 
		 * @return void
		 */
		public function callback_wp_enqueue_scripts() {
			//wp_enqueue_script( 'eoajax', WPEOMTM_TASK_URL . '/asset/js/eoajax.js', array( "jquery" ), WPEOMTM_TASK_VERSION );
			//wp_enqueue_script( 'wpeo-point-frontend-js', WPEOMTM_POINT_URL . '/asset/js/frontend.js', array( "jquery" ), WPEOMTM_POINT_VERSION );
		}
		
		public function increase_time( $point_id, $time_elapsed ) {
			$point = $this->show( $point_id );
			$point->option['time_info']['elapsed'] += $time_elapsed;
			$this->update($point);
		
			global $task_controller;
			$task = $task_controller->update_time( $point->post_id );
		
			return $task;
		}
		
		public function decrease_time( $point_id, $elapsed_time = 0 ) {
			$point = $this->show( $point_id );
		
			if ( $elapsed_time == 0 )
				$point->option['time_info']['elapsed'] = $elapsed_time;
			else
				$point->option['time_info']['elapsed'] -= $elapsed_time;
		
			$this->update( $point );
		
			global $task_controller;
			$task = $task_controller->update_time( $point->post_id );
		
			return $task;
		}
		
		public function send_comment_to( $old_task_id, $task_id, $point_id ) {
			global $point_time_controller;
			$list_comment = $point_time_controller->get_all_comment_in_point( $old_task_id, $point_id );
			
			if ( !empty( $list_comment ) ) {
				foreach ( $list_comment as $comment ) {
					$comment->post_id = $task_id;
					$point_time_controller->update( $comment, false );
				}
			}
		}
		
		public function get_created_point_by_user_id_and_date( $user_id, $start_date, $end_date ) {
			if ( empty( $user_id ) || empty( $start_date ) || empty( $end_date ) )
				return null;
				
			global $wpdb;
			
			$query =
			"SELECT DISTINCT point.comment_ID
			FROM {$wpdb->comments} as point
			WHERE	point.comment_parent = 0 AND
					point.user_id = %d AND
					point.comment_date BETWEEN %s AND %s";
			
			$list_comment = $wpdb->get_results( $wpdb->prepare( $query, array( $user_id, $start_date, $end_date ) ) );
				
			$list_point = array();
				
			if ( !empty( $list_comment ) ) {
				foreach ( $list_comment as $comment ) {
					$list_point[] = $this->show( $comment->comment_ID );
				}
			}
				
			return $list_point;
		}
		
		/**
		 * Récupères tous les points ou l'utilisateur $user_id à commenté.
		 * 
		 * @param int $user_id L'id de l'utilisateur
		 * @return NULL|Array point_model
		 */
		public function get_list_point_by_comment_user_id( $user_id ) {
			if ( empty( $user_id ) )
				return null;
			
			global $wpdb;
			
			$query = 
			"SELECT DISTINCT point.comment_ID 
			FROM {$wpdb->comments} as point
			JOIN {$wpdb->comments} as comment
			ON point.comment_ID=comment.comment_parent
			WHERE	comment.comment_parent != 0 AND 
					comment.user_id = %d";
			
			$list_comment = $wpdb->get_results( $wpdb->prepare( $query, array( $user_id ) ) );
			
			$list_point = array();
			
			if ( !empty( $list_comment ) ) {
				foreach ( $list_comment as $comment ) {
					$list_point[] = $this->show( $comment->comment_ID );
				}
			}
			
			return $list_point;
		}
		
		/**
		 * Récupères tous les point ou l'utilisateur $user_id à commenté et ou les 
		 * $start_date et $end_date corresponde.
		 * 
		 * @param int $user_id L'id de l'utilisateur
		 * @param string $start_date La date minimum
		 * @param string $end_date La date maximum
		 * @return NULL|Array point_model
		 */
		public function get_list_point_by_comment_user_id_and_date( $user_id, $start_date, $end_date ) {
			if ( empty( $user_id ) || empty( $start_date ) || empty( $end_date ) ) 
				return null;
			
			global $wpdb;
			
			$query = 
			"SELECT DISTINCT point.comment_ID 
			FROM {$wpdb->comments} as point
			JOIN {$wpdb->comments} as comment
			ON point.comment_ID=comment.comment_parent
			WHERE	comment.comment_parent != 0 AND 
					comment.user_id = %d AND
					comment.comment_date BETWEEN %s AND %s";
			
			$list_comment = $wpdb->get_results( $wpdb->prepare( $query, array( $user_id, $start_date, $end_date ) ) );
						
			$list_point = array();
			
			if ( !empty( $list_comment ) ) {
				foreach ( $list_comment as $comment ) {
					$list_point[] = $this->show( $comment->comment_ID );
				}
			}
						
			return $list_point;
		}
		
		public function get_completed_point_by_user_id_and_date( $user_id, $start_date, $end_date ) {
			if ( empty( $user_id ) || empty( $start_date ) || empty( $end_date ) )
				return null;
				
			$list_point = $this->index( 0, array( 'post_type' => 'wpeo-task', 'status' => '-34070' ) );
			$list_point_completed = array();
			
			if ( !empty( $list_point ) ) {
				foreach ( $list_point as $point ) {
					if ( !empty( $point->option['time_info']['completed_point'][$user_id] ) ) {
						foreach( $point->option['time_info']['completed_point'][$user_id] as $date_completed ) {

							if( ( $date_completed > $start_date ) && ( $date_completed < $end_date ) ) {
								$point->completed_date = $date_completed;
								$list_point_completed[] = $point;
							}
							
							break;
						}
					}
				}
			}
			
			return $list_point_completed;
		}
		
		public static function get_point_name_by_id( $point_id ) {
			if( empty( $point_id ) ) 
				return __( 'Point not found', 'wpeopoint-i18n' );
			
			global $point_controller;
			$point = $point_controller->show( $point_id );
			
			if( empty( $point ) )
				return __( 'Point not found', 'wpeopoint-i18n' );
			
			return $point->content;
		}

		public function get_all_point_wpshop_user() {
			global $wpdb;

			
			
			$list_point = $wpdb->get_results( $query );
			
			return $list_point;
		}
		
		/**
		 * Static method for render list point in object
		 * 
		 * @param int $object_id
		 * @param array ( point_mdl_01, point_mdl_01, .. ) $list_point The list of point in the object
		 * 
		 * @return void
		 */
		public static function render_point( $object_id, $list_point ) {
			$key = 0;
			
			$count_point_completed = 0;
			
			if( !empty( $list_point ) ) {
				foreach( $list_point as $point ) {
					if( $point->option['point_info']['completed'] ) {
						$count_point_completed++;
					}
				}
			}
			
			require( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'list', 'point' ) );
		}
	
		public static function render_point_frontend( $task ) {
			global $task_controller;
			$list_point = $task_controller->get_point( $task->option['task_info']['order_point_id'] );
			require( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'frontend', 'list', 'point' ) );
		}
	}
	
	global $point_controller;
	$point_controller = new point_controller_01();
	
}