<?php

if ( ! defined( 'ABSPATH' ) ) exit;

class point_ajax_controller_01 {
	public function __construct() {
		/** Point */
		add_action( 'wp_ajax_create_point', array( &$this, 'ajax_create_point' ) );
		add_action( 'wp_ajax_delete_point', array( &$this, 'ajax_delete_point' ) );
		add_action( 'wp_ajax_edit_point', array( &$this, 'ajax_edit_point' ) );
		add_action( 'wp_ajax_edit_order_point', array( &$this, 'ajax_edit_order_point' ) );
		
		/** Point time */
		add_action( 'wp_ajax_thickbox_point_time', array( &$this, 'ajax_thickbox_point_time' ) );
		add_action( 'wp_ajax_create_point_time', array( &$this, 'ajax_create_point_time' ) );
		add_action( 'wp_ajax_get_point_time', array( &$this, 'ajax_get_point_time' ) );
		add_action( 'wp_ajax_delete_point_time', array( &$this, 'ajax_delete_point_time' ) );
		
		/** Dashboard */
		add_action( 'wp_ajax_load_dashboard_point', array( &$this, 'ajax_load_dashboard_point' ) );
	}
	
	/**
	 * Créer un point avec le status -34070 et assignes le à une tâche. Ensuite renvoie 
	 * le template backend-point. / Create an point with the status -34070 and assign it
	 * to a task. Then send the template backend-point.
	 * 
	 * @param int $_POST['post_id'] ID de la tâche / The task ID
	 * @param string $_POST['content'] Le contenu du point / The point content
	 * 
	 * @return string Le template d'un point / The template of point
	 */
	public function ajax_create_point() {
		global $task_ctr_01;
		global $point_controller_01;
		
		$_POST['point']['author_id'] = get_current_user_id();
		$_POST['point']['status'] = '-34070';
		$point = $point_controller_01->create( $_POST['point'] );
		
		/** Required for the template */
		$object_id	= $_POST['point']['post_id'];
		
		/** Add to the order point */
		$task = $task_ctr_01->show( $object_id );
		$task->option['task_info']['order_point_id'][] = ( int ) $point->id;
		$task_ctr_01->update( $task );
		
		/** Log la création du point / Log the creation of point */
		wpeologs_ctr::log_datas_in_files( 'wpeo_project',
			array(
				'object_id' => $object_id,
				'message' => sprintf( __( 'Creation of point #%d with the content : %s for the task #%d', 'wpeotask-i18n'), $point->id, $point->content, $object_id ),
			), 0 );
		
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'point' ) );
		$template = ob_get_clean();
		
		wp_die( $template );
	}
	
	/**
	 * Supprimes un point grâce à son point ID. Supprimes également le temps passé dans 
	 * la tâche en rapport avec ce point. Enlèves le point de order_point_id dans 
	 * la tâche et met à jours la tâche. / Delete an point by its point ID. Also delete 
	 * the elapsed time in the task in connection with this point. Take off the point 
	 * in order_point_id in the task and update this.
	 * 
	 * @param int $_POST['post_id'] ID de la tâche / The task ID
	 * @param int $_POST['point_id'] ID du point / The point ID
	 * 
	 * @return json task_mdl_01 Object
	 */
	public function ajax_delete_point() {
		header( 'Content-Type: application/json' );
		global $task_ctr_01;
		global $point_controller_01;
		
		$point 	= $point_controller_01->show( $_POST['point_id'] );
		$task 	= $point_controller_01->decrease_time( $_POST['point_id'] );
		
		if( ( $key = array_search( $_POST['point_id'], $task->option['task_info']['order_point_id'] ) ) !== false ) {
			unset( $task->option['task_info']['order_point_id'][$key] );
		}
				
		$task_ctr_01->update( $task );
		
		/** Log la suppression du point / Log the deletion of point */
		wpeologs_ctr::log_datas_in_files( 'wpeo_project',
		array(
			'object_id' => $_POST['point_id'],
			'message' => sprintf( __( 'The point #%d was deleted for the task #%d. The elapsed time for this point was %d minute(s). The elapsed time for this task is now %d minute(s)', 'wpeotask-i18n'), $point->id, $task->id, $point->option['time_info']['elapsed'], $task->option['time_info']['elapsed'] ),
		), 0 );
		
		wp_die( json_encode( array( 'task' => $task ) ) );
	}
	
	/**
	 * Met à jour le contenu d'un point. / Update the content of point.
	 * 
	 * @param int $_POST['point']['post_id'] L'ID du post / The post ID
	 * @param int $_POST['point']['id'] L'ID du point / The point ID
	 * @param bool $_POST['point']['option']['point_info']['completed'] Le point est-il fait ? / The point is done ?
	 * @param string $_POST['point']['content'] Le contenu du point / The point content
	 * 
	 * @return void
	 */
	public function ajax_edit_point() {
		global $point_controller_01;
		$point_controller_01->update( $_POST['point'] );

		wpeologs_ctr::log_datas_in_files( 'wpeo_project',
		array(
			'object_id' => $_POST['point']['id'],
			'message' => sprintf( __( 'The point #%d was updated with the content : %s and set to completed : %s', 'wpeotask-i18n'), $_POST['point']['id'], $_POST['point']['content'], $_POST['point']['option']['point_info']['completed'] ),
		), 0 );
		
		wp_die();
	}
	
	/**
	 * Met à jour la meta order_point_id d'une tâche / Update the meta order_point_id
	 * on a task.
	 * 
	 * @param int $_POST['object_id'] L'ID de la tâche / The task ID
	 * @param array $_POST['order_point_id'] Le tableau avec les id des points / The array of 
	 * id points
	 * 
	 * @return void
	 */
	public function ajax_edit_order_point() {
		global $task_ctr_01;
		$task = $task_ctr_01->show( $_POST['object_id'] );
		
		/** Get all completed point in the task for don't forget it in the order point id */
		foreach( $task->point as $point ) {
			if( $point->option['point_info']['completed'] )
				$_POST['order_point_id'][] = (int)$point->id;
		}
				
		$task->option['task_info']['order_point_id'] = $_POST['order_point_id'];
		$task_ctr_01->update( $task );
		
		wpeologs_ctr::log_datas_in_files( 'wpeo_project',
		array(
			'object_id' => $_POST['object_id'],
			'message' => sprintf( __( 'The point order for the task #%d was reassigned : %s', 'wpeotask-i18n'), $_POST['object_id'], implode( ',', $_POST['order_point_id'] ) ),
		), 0 );
		
		wp_die();
	}

	public function ajax_load_dashboard_point() {
		global $task_ctr_01;
		global $point_controller_01;
		global $point_time_controller_01;
		global $user_controller_01;
		
		$task 				= $task_ctr_01->show( $_POST['task_id'] );
		$point 				= $point_controller_01->show( $_POST['point_id'] );
		$point_user 		= $user_controller_01->show( $point->author_id );
		$list_point_time 	= $point_time_controller_01->index( $task->id, array( 'parent' => $point->id, 'status' => -34070 ) );
		$list_user_in 		= array();
		
		if ( !empty( $list_point_time ) ) {
			foreach ( $list_point_time as $point_time ) {
				if ( empty( $list_user_in[$point_time->author_id] ) ) {
					$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
				}
			}
		}
		
		require( wpeo_tag_template_ctr::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'window', 'dashboard-point' ) );
		
		wp_die();
	}
	
	public function ajax_create_point_time() {
		header('Content-Type: application/json');
		global $point_time_controller_01;
		
		$response = array();
		
		$_POST['point_time']['date'] .= ' ' . $_POST['point_time']['time'];
		
		if ( !empty( $_POST['point_time_id'] ) ) {
			/** Edit the point */
			$point_time 									= $point_time_controller_01->show($_POST['point_time_id']);
			$point_time->option['time_info']['old_elapsed'] = $point_time->option['time_info']['elapsed'];
			$point_time->date 								= $_POST['point_time']['date'];
			$point_time->option['time_info']['elapsed'] 	= $_POST['point_time']['option']['time_info']['elapsed'];
			$point_time->content 							= $_POST['point_time']['content'];
			
			$response = $point_time_controller_01->update($point_time);			
		}
		else {
			/** Add the point */
			$_POST['point_time']['status'] = '-34070';
			
			$response 	= $point_time_controller_01->create( $_POST['point_time'] );
			$point_time = $point_time_controller_01->show( $response['point_time_id'] );
		}
		
		$list_user_in = array();
		
		if ( !empty( $point_time ) ) {
			$list_user_in[$point_time->author_id] = get_userdata( $point_time->author_id );
		}
		
		ob_start();
		require_once( wpeo_template_01::get_template_part( WPEOMTM_POINT_DIR, WPEOMTM_POINT_TEMPLATES_MAIN_DIR, 'backend', 'point', 'time' ) );
		$response['template'] = ob_get_clean();
		
		wp_die( json_encode( $response ) );
	}

	public function ajax_get_point_time() {
		header('Content-Type: application/json');
		$response = array();
		global $point_time_controller_01;
		$point_time = $point_time_controller_01->show( $_POST['point_time_id'] );
		
		$date = explode( ' ', $point_time->date );
		$response['date'] 		= $date[0];
		$response['time']		= $date[1];
		$response['elapsed'] 	= $point_time->option['time_info']['elapsed'];
		$response['content']	= $point_time->content;
		
		wp_die(json_encode($response));
	}
	
	public function ajax_delete_point_time() {
		header( 'Content-Type: application/json' );
		global $point_time_controller_01;
		
		$response = array();
		
		$response['task'] = $point_time_controller_01->delete( $_POST['point_time_id'] );
		
		wp_die( json_encode( $response ) );
	}
}