<?php 

/**
 * Pour avoir l'object name des points
 * @author Jimmy Latour
 * @version 0.1
 */

class point_time_controller_01 extends comment_ctr_01 {
	protected $model_name 	= 'point_time_mdl_01';
	protected $meta_key		= 'wpeo_point_time';
	
	/** Défini la route par défaut permettant d'accèder aux temps pointés depuis WP Rest API  / Define the default route for accessing to point time from WP Rest API */
	protected $base = 'point_time';
	protected $version = '0.1';
	
	public function __construct() {
 		include_once( WPEOMTM_POINT_PATH . '/model/point_time.model.01.php' );
	}

	public function create( $data ) {
		$object = parent::create( $data) ;
		global $point_controller;
		
		/** Update time in point */
		$task = $point_controller->increase_time( $object->parent_id, $object->option['time_info']['elapsed'] );
		
		return array('task' => $task, 'point_time_id' => $object->id);
	}
	
	public function update( $data, $update_time = true ) {
		$object = parent::update( $data );
		$task = null;
		
		if( $update_time ) {
			global $point_controller;
			$task = $point_controller->decrease_time( $data->parent_id, $data->option['time_info']['old_elapsed'] );
			$task = $point_controller->increase_time( $data->parent_id, $data->option['time_info']['elapsed'] );
		}
		
		return array('task' => $task, 'point_time_id' => $data->id, 'edit' => 'fzeafzef' );
	}
	
	public function delete( $id ) {
		global $point_controller;
		$point_time 	= $this->show( $id );
		
		$task = $point_controller->decrease_time( $point_time->parent_id, $point_time->option['time_info']['elapsed'] );
		
		parent::delete( $id );
		
		return $task;
	}

	public function get_all_comment_in_point( $task_id, $point_id ) {
		$list_comment = $this->index( $task_id, array( 'parent' => $point_id, 'status' => -34070 ) );
		
		return $list_comment;
	}	
	
	public function get_all_comment( $data_order = "comment_ID", $order = "ASC", $limit = 10, $start_limit = 0 ) {
		global $wpdb;
		$start_limit = $limit * $start_limit;
		
		$query =
		"SELECT * FROM (
			SELECT comment.comment_ID, comment.comment_date FROM {$wpdb->comments} AS comment 
			JOIN {$wpdb->usermeta} AS user ON comment.user_id = user.user_id 
			WHERE comment.comment_parent != 0 AND 
			comment.comment_approved = '-34070' AND
			comment.comment_type = '' AND
			user.meta_key= 'wp_user_level' AND 
			user.meta_value= 0 
		
			UNION ALL
			SELECT c.comment_ID, c.comment_date FROM {$wpdb->comments} as c 
			JOIN {$wpdb->users} as u ON c.user_id=u.ID
			JOIN {$wpdb->usermeta} as um ON ( 
		    	c.user_id=um.user_id AND 
		    	um.meta_key='wp_user_level' AND 
		    	um.meta_value=0 
		    )
		    WHERE c.comment_parent = 0 AND
		    c.comment_approved = '-34070'
		) as t
		ORDER BY comment_date DESC
		LIMIT " . $start_limit . ", " . $limit;
		
		$list_comment = $wpdb->get_results( $query );
		$list_comment_mdl = array();
		
		if ( !empty( $list_comment ) ) {
			foreach ( $list_comment as $comment ) {
				$list_comment_mdl[] = $this->show( $comment->comment_ID );
			}
		}
		
		
		return $list_comment_mdl;
	}

	public function get_list_comment_by_user_id_and_date( $user_id, $start_date, $end_date ) {
		if ( empty( $user_id ) || empty( $start_date ) || empty( $end_date ) )
			return null;
			
		global $wpdb;
			
		$query =
			"SELECT DISTINCT comment_ID
			FROM {$wpdb->comments}
			WHERE	comment_parent != 0 AND
					user_id = %d AND
					comment_date BETWEEN %s AND %s";
			
		$list_comment = $wpdb->get_results( $wpdb->prepare( $query, array( $user_id, $start_date, $end_date ) ) );
		
		$list_point_time = array();
			
		if ( !empty( $list_comment ) ) {
			foreach ( $list_comment as $comment ) {
			$list_point_time[] = $this->show( $comment->comment_ID );
			}
		}
		
		return $list_point_time;
	}
	
	public function get_count_comment() {
		global $wpdb;
		
		$count_comment = 0;
		
		$query =
		"SELECT COUNT(*) 
		FROM ( 
		    SELECT distinct comment.comment_ID 
		    FROM {$wpdb->comments} AS comment 
		    JOIN {$wpdb->usermeta} AS user ON comment.user_id = user.user_id 
		    WHERE comment.comment_parent != 0 AND 
		    comment.comment_approved = '-34070' AND 
		    comment.comment_type = '' AND 
		    user.meta_key= 'wp_user_level' AND 
		    user.meta_value= 0 
		    
		    UNION ALL 
		    SELECT distinct c.comment_ID FROM {$wpdb->comments} as c 
		    JOIN {$wpdb->users} as u ON c.user_id=u.ID 
		    JOIN {$wpdb->usermeta} as um ON ( c.user_id=um.user_id AND um.meta_key='wp_user_level' AND um.meta_value=0 ) 
		    WHERE c.comment_parent = 0 AND 
		    c.comment_approved= '-34070'  
		) as x";
		
		$count_comment = $wpdb->get_var( $query );

		return $count_comment;
	}
}

global $point_time_controller;
$point_time_controller = new point_time_controller_01();

?>